"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _debug = _interopRequireDefault(require("debug"));
var _core = require("@verdaccio/core");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const debug = (0, _debug.default)('verdaccio:plugin:auth:memory:user');
const {
  Plugin
} = _core.pluginUtils;
class Memory extends Plugin {
  constructor(config, appOptions) {
    super(config, appOptions);
    this._users = config.users || {};
    this._config = config;
    this._logger = appOptions.logger;
    this._app_config = appOptions.config;
  }
  authenticate(user, password, cb) {
    debug('authenticate %o:%o', user, password);
    const userCredentials = this._users[user];
    if (!userCredentials) {
      debug('user %o does not exist', user);
      return cb(null, false);
    }
    if (password !== userCredentials.password) {
      const err = _core.errorUtils.getUnauthorized(_core.API_ERROR.BAD_USERNAME_PASSWORD);
      debug('password invalid for: %o', user);
      return cb(err);
    }

    // authentication succeeded!
    // return all usergroups this user has access to;
    debug('authentication succeed for %o', user);
    return cb(null, [user]);
  }
  adduser(user, password, cb) {
    if (this._users[user]) {
      debug('user %o already exist', user);
      return cb(null, true);
    }
    if (this._app_config.max_users) {
      if (Object.keys(this._users).length >= this._app_config.max_users) {
        const err = _core.errorUtils.getConflict(_core.API_ERROR.MAX_USERS_REACHED);
        debug(_core.API_ERROR.MAX_USERS_REACHED);
        return cb(err);
      }
    }
    this._users[user] = {
      name: user,
      password: password
    };
    debug('user added succeeded for %o', user);
    cb(null, user);
  }
  changePassword(username, password, newPassword, cb) {
    const user = this._users[username];
    debug('init change password for %o', user === null || user === void 0 ? void 0 : user.name);
    if (user && user.password === password) {
      user.password = newPassword;
      this._users[username] = user;
      debug('user changed password succeeded for %o', user === null || user === void 0 ? void 0 : user.name);
      cb(null, true);
    } else {
      const err = _core.errorUtils.getNotFound('user not found');
      this._logger.debug({
        user: username
      }, 'change password user  @{user} not found');
      debug('change password user for %o not found', user === null || user === void 0 ? void 0 : user.name);
      return cb(err);
    }
  }
  allow_access(user, pkg, cb) {
    var _pkg$access, _pkg$access2, _pkg$access3, _pkg$access4;
    debug('allow access for %o', user);
    if (pkg !== null && pkg !== void 0 && (_pkg$access = pkg.access) !== null && _pkg$access !== void 0 && _pkg$access.includes('$all') || pkg !== null && pkg !== void 0 && (_pkg$access2 = pkg.access) !== null && _pkg$access2 !== void 0 && _pkg$access2.includes('$anonymous')) {
      debug('%o has been granted access', user === null || user === void 0 ? void 0 : user.name);
      return cb(null, true);
    }
    if (!(user !== null && user !== void 0 && user.name)) {
      const err = _core.errorUtils.getForbidden('not allowed to access package');
      this._logger.debug({
        user: user.name
      }, 'user: @{user} not allowed to access package');
      debug('%o not allowed to access package err', user === null || user === void 0 ? void 0 : user.name, err.message);
      return cb(err);
    }
    if (pkg !== null && pkg !== void 0 && (_pkg$access3 = pkg.access) !== null && _pkg$access3 !== void 0 && _pkg$access3.includes(user === null || user === void 0 ? void 0 : user.name) || pkg !== null && pkg !== void 0 && (_pkg$access4 = pkg.access) !== null && _pkg$access4 !== void 0 && _pkg$access4.includes('$authenticated')) {
      debug('%o has been granted access', user === null || user === void 0 ? void 0 : user.name);
      return cb(null, true);
    }
    const err = _core.errorUtils.getForbidden('not allowed to access package');
    debug('%o not allowed to access package err', user === null || user === void 0 ? void 0 : user.name, err === null || err === void 0 ? void 0 : err.message);
    return cb(err);
  }
  allow_publish(user, pkg, cb) {
    var _pkg$publish, _pkg$publish2, _pkg$publish3, _pkg$publish4;
    if (pkg !== null && pkg !== void 0 && (_pkg$publish = pkg.publish) !== null && _pkg$publish !== void 0 && _pkg$publish.includes('$all') || pkg !== null && pkg !== void 0 && (_pkg$publish2 = pkg.publish) !== null && _pkg$publish2 !== void 0 && _pkg$publish2.includes('$anonymous')) {
      debug('%o has been granted to publish', user === null || user === void 0 ? void 0 : user.name);
      return cb(null, true);
    }
    if (!(user !== null && user !== void 0 && user.name)) {
      const err = _core.errorUtils.getForbidden('not allowed to publish package');
      debug('%o not allowed to publish package err %o', user === null || user === void 0 ? void 0 : user.name, err.message);
      return cb(err);
    }
    if (pkg !== null && pkg !== void 0 && (_pkg$publish3 = pkg.publish) !== null && _pkg$publish3 !== void 0 && _pkg$publish3.includes(user.name) || pkg !== null && pkg !== void 0 && (_pkg$publish4 = pkg.publish) !== null && _pkg$publish4 !== void 0 && _pkg$publish4.includes('$authenticated')) {
      return cb(null, true);
    }
    const err = _core.errorUtils.getForbidden('not allowed to publish package');
    debug('%o not allowed to publish package err %o', user === null || user === void 0 ? void 0 : user.name, err.message);
    return cb(err);
  }
}
exports.default = Memory;
//# sourceMappingURL=Memory.js.map